@@ -72,15 +72,15 @@ void SignatureTester::testSignatures()
     QCOMPARE(sig2.withSeparator(), QStringLiteral("-- <br><b>Hello</b> World"));
     QVERIFY(!sig2.isEnabledSignature());
 
+    const QString dataFilePath = QStringLiteral(SIGNATURETEST_DATA_FILE);
     // Read this very file in, we use it for the tests
-    QFile thisFile(QStringLiteral(__FILE__));
+    QFile thisFile(dataFilePath);
     thisFile.open(QIODevice::ReadOnly);
     QString fileContent = QString::fromUtf8(thisFile.readAll());
 
     if (!QStandardPaths::findExecutable(QStringLiteral("cat")).isEmpty()) {
         Signature sig3;
-        const QString tempFile = KShell::quoteArg(QLatin1String(KIDENTITYMANAGER_DATA_DIR) + QStringLiteral(__FILE__));
-        sig3.setPath(QStringLiteral("cat ") + KShell::quoteArg(tempFile), true);
+        sig3.setPath(QStringLiteral("cat ") + KShell::quoteArg(dataFilePath), true);
         QCOMPARE(sig3.rawText(), fileContent);
         QVERIFY(!sig3.isInlinedHtml());
         QVERIFY(sig3.text().isEmpty());
@@ -90,7 +90,7 @@ void SignatureTester::testSignatures()
     }
 
     Signature sig4;
-    sig4.setPath(QStringLiteral(__FILE__), false);
+    sig4.setPath(dataFilePath, false);
     QCOMPARE(sig4.rawText(), fileContent);
     QVERIFY(!sig4.isInlinedHtml());
     QVERIFY(sig4.text().isEmpty());
@@ -204,7 +204,8 @@ void SignatureTester::testImages()
     QString image1Path = QCoreApplication::applicationDirPath() + QLatin1String("/image.png");
     img.save(image1Path);
 
-    QImage image1, image2;
+    QImage image1;
+    QImage image2;
     QVERIFY(image1.load(image1Path));
     QVERIFY(image2.load(image1Path));
     QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/emailidentities/unittest/");
