@@ -44,11 +44,22 @@ public:
     QList<uint> mUoidList;
     IdentityManager *const mIdentityManager;
     IdentityCombo *const q;
+    bool showDefault = false;
 };
 
 void KIdentityManagement::IdentityComboPrivate::reloadCombo()
 {
-    const QStringList identities = mIdentityManager->identities();
+    QStringList identities;
+    identities.reserve(mIdentityManager->identities().count());
+    IdentityManager::ConstIterator it;
+    IdentityManager::ConstIterator end(mIdentityManager->end());
+    for (it = mIdentityManager->begin(); it != end; ++it) {
+        if (showDefault && it->isDefault()) {
+            identities << QString(it->identityName() + i18nc("Default identity", " (default)"));
+        } else {
+            identities << it->identityName();
+        }
+    }
     // the IM should prevent this from happening:
     assert(!identities.isEmpty());
     q->clear();
@@ -73,17 +84,14 @@ IdentityCombo::IdentityCombo(IdentityManager *manager, QWidget *parent)
 {
     d->reloadCombo();
     d->reloadUoidList();
-    connect(this, QOverload<int>::of(&IdentityCombo::activated), this, &IdentityCombo::slotEmitChanged);
+    connect(this, &IdentityCombo::activated, this, &IdentityCombo::slotEmitChanged);
     connect(this, &IdentityCombo::identityChanged, this, &IdentityCombo::slotUpdateTooltip);
-    connect(manager, QOverload<>::of(&IdentityManager::changed), this, &IdentityCombo::slotIdentityManagerChanged);
+    connect(manager, qOverload<>(&IdentityManager::changed), this, &IdentityCombo::slotIdentityManagerChanged);
     connect(manager, &IdentityManager::deleted, this, &IdentityCombo::identityDeleted);
     slotUpdateTooltip(currentIdentity());
 }
 
-IdentityCombo::~IdentityCombo()
-{
-    delete d;
-}
+IdentityCombo::~IdentityCombo() = default;
 
 QString IdentityCombo::currentIdentityName() const
 {
@@ -95,6 +103,11 @@ uint IdentityCombo::currentIdentity() const
     return d->mUoidList.at(currentIndex());
 }
 
+bool IdentityCombo::isDefaultIdentity() const
+{
+    return d->mUoidList.at(currentIndex()) == d->mIdentityManager->defaultIdentity().uoid();
+}
+
 void IdentityCombo::setCurrentIdentity(const Identity &identity)
 {
     setCurrentIdentity(identity.uoid());
@@ -177,3 +190,11 @@ IdentityManager *IdentityCombo::identityManager() const
 {
     return d->mIdentityManager;
 }
+
+void IdentityCombo::setShowDefault(bool showDefault)
+{
+    if (d->showDefault != showDefault) {
+        d->showDefault = showDefault;
+        d->reloadCombo();
+    }
+}
