@@ -13,8 +13,8 @@
 
 #include <QHash>
 #include <QImage>
-#include <QList>
 #include <QString>
+#include <memory>
 
 namespace KIdentityManagement
 {
@@ -236,7 +236,7 @@ protected:
 
 private:
     //@cond PRIVATE
-    SignaturePrivate *const d;
+    std::unique_ptr<SignaturePrivate> const d;
     //@endcond
 };
 
