@@ -49,10 +49,10 @@ namespace KIdentityManagement
    @internal
   */
 //@cond PRIVATE
-class Q_DECL_HIDDEN SignatureConfigurator::Private
+class Q_DECL_HIDDEN SignatureConfiguratorPrivate
 {
 public:
-    Private(SignatureConfigurator *parent);
+    explicit SignatureConfiguratorPrivate(SignatureConfigurator *parent);
     void init();
     // Returns the current text of the textedit as HTML code, but strips
     // unnecessary tags Qt inserts
@@ -73,19 +73,19 @@ public:
 };
 //@endcond
 
-SignatureConfigurator::Private::Private(SignatureConfigurator *parent)
+SignatureConfiguratorPrivate::SignatureConfiguratorPrivate(SignatureConfigurator *parent)
     : q(parent)
     , inlinedHtml(true)
 {
 }
 
-QString SignatureConfigurator::Private::asCleanedHTML() const
+QString SignatureConfiguratorPrivate::asCleanedHTML() const
 {
     QString text = mTextEdit->toHtml();
 
     // Beautiful little hack to find the html headers produced by Qt.
     QTextDocument textDocument;
-    QString html = textDocument.toHtml();
+    const QString html = textDocument.toHtml();
 
     // Now remove each line from the text, the result is clean html.
     const QStringList lst = html.split(QLatin1Char('\n'));
@@ -95,7 +95,7 @@ QString SignatureConfigurator::Private::asCleanedHTML() const
     return text;
 }
 
-void SignatureConfigurator::Private::init()
+void SignatureConfiguratorPrivate::init()
 {
     auto vlay = new QVBoxLayout(q);
     vlay->setObjectName(QStringLiteral("main layout"));
@@ -127,15 +127,15 @@ void SignatureConfigurator::Private::init()
     auto widgetStack = new QStackedWidget(q);
     widgetStack->setEnabled(false); // since !mEnableCheck->isChecked()
     vlay->addWidget(widgetStack, 1);
-    q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
-    q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::highlighted), widgetStack, &QStackedWidget::setCurrentIndex);
+    q->connect(mSourceCombo, &QComboBox::currentIndexChanged, widgetStack, &QStackedWidget::setCurrentIndex);
+    q->connect(mSourceCombo, &QComboBox::highlighted, widgetStack, &QStackedWidget::setCurrentIndex);
     // connects for the enabling of the widgets depending on
     // signatureEnabled:
     q->connect(mEnableCheck, &QCheckBox::toggled, mSourceCombo, &QComboBox::setEnabled);
     q->connect(mEnableCheck, &QCheckBox::toggled, widgetStack, &QStackedWidget::setEnabled);
     q->connect(mEnableCheck, &QCheckBox::toggled, label, &QLabel::setEnabled);
     // The focus might be still in the widget that is disabled
-    q->connect(mEnableCheck, &QCheckBox::clicked, mEnableCheck, QOverload<>::of(&QCheckBox::setFocus));
+    q->connect(mEnableCheck, &QCheckBox::clicked, mEnableCheck, qOverload<>(&QCheckBox::setFocus));
 
     int pageno = 0;
     // page 0: input field for direct entering:
@@ -263,15 +263,12 @@ void SignatureConfigurator::Private::init()
 
 SignatureConfigurator::SignatureConfigurator(QWidget *parent)
     : QWidget(parent)
-    , d(new Private(this))
+    , d(new SignatureConfiguratorPrivate(this))
 {
     d->init();
 }
 
-SignatureConfigurator::~SignatureConfigurator()
-{
-    delete d;
-}
+SignatureConfigurator::~SignatureConfigurator() = default;
 
 bool SignatureConfigurator::isSignatureEnabled() const
 {
