@@ -19,11 +19,11 @@ public:
         : QObject(parent)
         , mIdentityManager(/*ro=*/true)
     {
-        connect(&mIdentityManager, QOverload<>::of(&IdentityManager::changed), this, &IdendentitiesCache::slotIdentitiesChanged);
+        connect(&mIdentityManager, qOverload<>(&IdentityManager::changed), this, &IdendentitiesCache::slotIdentitiesChanged);
         slotIdentitiesChanged();
     }
 
-    const QSet<QString> &emails()
+    const QSet<QString> &emails() const
     {
         return mEmails;
     }
